@@ -1,4 +1,4 @@
-from sys import argv
+from sys import argv; import os
 from . import update_widgets, gorilla_clean, stk_swx, widgets_help, tuner
 
 modules_to_alias={
@@ -6,7 +6,7 @@ modules_to_alias={
     "widgets_help": widgets_help,
     "gorilla_clean": gorilla_clean,
     "stk_swx": stk_swx,
-    "tuner": tuner
+    "tuner": tuner,
 }
 
 cmd = argv[1]
