@@ -7,16 +7,15 @@ def main():
     with open(zprofile,"r") as reader:
 
         lines = reader.readlines()
-        fp = __file__
-        to_find = f"{fp[:fp.rfind('/')]}/set_aliases.sh"
         newlines = []
         
         for line in lines: 
-            if not ( "spl_widgets" in line and "alias" in line ):
+            if "spl_widgets" not in line:
                 newlines.append(line)
         
-        if to_find not in newlines:
-            newlines.append(to_find)
+        for module in modules_to_alias:
+            alias_str = f'alias {module}="python3 -m spl_widgets {module}\n'
+            newlines.append(alias_str)
 
     with open(zprofile, "w") as writer:
         writer.writelines(newlines)
